@@ -3,7 +3,6 @@
 #' @param x a df
 #'
 #' @return an integer; number of dupe rows
-#' @keywords internal
 #'
 n_dupes <- function(x){(x %>% nrow) - (dplyr::distinct(x) %>% nrow) -> dupes ;dupes}
 
@@ -25,7 +24,7 @@ confirm_distinct <- function(.data, ...) {
 
   .data %>%
     dplyr::ungroup() %>%
-    select_otherwise(..., return_type = "df") -> .data1
+    select_otherwise(..., otherwise = tidyselect::everything(), return_type = "df") -> .data1
 
   .data1 %>% names() %>% rlang::syms(.) -> cols
 
